//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Kanchan](index.md)/[waiting](waiting.md)

# waiting

[common]\
open override val [waiting](waiting.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../-tile/index.md)&gt;

进张
